﻿/*!
 *      @date   2011/09/08
 *      @file   dhwr_ink.h
 *      @author shchoi
 *
 *      Copyright (c) 2016 by SELVAS AI Inc. All rights reserved.
 */

#ifndef __DHWR_INK_OBJECT_H__
#define __DHWR_INK_OBJECT_H__ 1

#include "dhwr_define.h"

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @defgroup  InkObject InkObject APIs
 * @ingroup   Main
 * @brief     좌표를 관리하는 InkObject관련 함수
 */

/*@{*/

//! Ink Object Handle
typedef const void* DHWRInkObject;

/*!
 *  @brief 잉크 오브젝트를 생성한다
 *  @return DHWRInkObject
 */
DHWR_API DHWRInkObject DHWRCreateInkObject(void);

/*!
 *  @brief 잉크 오브젝트를 제거한다
 *  @param [in] ink 잉크 오브젝트
 *  @return void
 */
DHWR_API void DHWRDestroyInkObject(DHWRInkObject ink);

/*!
 *  @brief 인식엔진에서 인식할 터치 좌표(잉크 좌표)를 추가함
 *  @param [in] ink 잉크 오브젝트
 *  @param [in] x x 좌표
 *  @param [in] y y 좌표
 *  @return @ref DHWR_ERROR_CODE "Error Code"
 */
DHWR_API unsigned long DHWRAddPoint(DHWRInkObject ink, const int x, const int y);

/*!
 *  @brief TouchUp 이벤트에 의해 한 획의 입력을 마쳤을 때 호출함
 *  @param [in] ink 잉크 오브젝트
 *  @return @ref DHWR_ERROR_CODE "Error Code"
 */
DHWR_API unsigned long DHWREndStroke(DHWRInkObject ink);

/*!
 *  @brief 입력한 좌표 데이터를 초기화함
 *  @param [in] ink 잉크 오브젝트
 *  @return @ref DHWR_ERROR_CODE "Error Code"
 */
DHWR_API unsigned long DHWRInkClear(DHWRInkObject ink);

/*!
 *  @brief 입력된 잉크 인덱스 값에 해당하는 잉크 좌표값을 받아옴
 *  @param [in] ink 잉크 오브젝트
 *  @param [in] index 받아오고자 하는 잉크의 인덱스
 *  @param [out] x 해당 잉크의 x 좌표값
 *  @param [out] y 해당 잉크의 y 좌표값
 *  @return @ref DHWR_ERROR_CODE "Error Code"
 */
DHWR_API unsigned long DHWRGetInkPoint(DHWRInkObject ink, const int index,
  int* x, int* y);

/*!
 *  @brief 현재까지 입력된 잉크의 개수를 받아옴
 *  @param [in] ink 잉크 오브젝트
 *  @param [out] count 잉크의 개수
 *  @return @ref DHWR_ERROR_CODE "Error Code"
 */
DHWR_API unsigned long DHWRGetInkCount(DHWRInkObject ink, int* count);

/*@}*/

#ifdef __cplusplus
}
#endif

#endif // __DHWR_INK_OBJECT_H__
